(sql-array array-type array-items)Returns a SQL ARRAY(...) object, typically for use with a large (>32k) list of items that need to be passed to a SQL function.
array-type: the SQL name of the type of the array-items (e.g. 'varchar' or 'uuid').
array-items: the elements that populate the returned SQL ARRAY object.
Returns a SQL ARRAY(...) object, typically for use with a large (>32k) list of items that need to be passed to a SQL function. array-type: the SQL name of the type of the `array-items` (e.g. 'varchar' or 'uuid'). array-items: the elements that populate the returned SQL ARRAY object.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |